==> ace_5.4.2.1.0.orig.tar.gz: ACE_wrappers/TAO/orbsvcs/FTRT_Event_Service/Factory_Service/EventChannelFactory_i.h <==
// -*- C++ -*-

//=============================================================================
/**
 *  @file   EventChannelFactory_i.h
 *
 *  EventChannelFactory_i.h,v 1.6 2004/02/07 14:10:36 jwillemsen Exp
 *
 *  @author Huang-Ming Huang <hh1@cse.wustl.edu>
 */
//=============================================================================

#ifndef EVENTCHANNELFACTORY_I_H
#define EVENTCHANNELFACTORY_I_H

#include "orbsvcs/orbsvcs/FT_CORBAS.h"
#include "ace/Synch.h"
#include "ace/Hash_Map_Manager_T.h"

#if !defined (ACE_LACKS_PRAGMA_ONCE)
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */

class EventChannelFactory_i : public POA_PortableGroup::GenericFactory {
public:
  EventChannelFactory_i(const char* conf_filename, CORBA::ORB_ptr);

  virtual CORBA::Object_ptr create_object (
    const char * type_id,
    const PortableGroup::Criteria & the_criteria,
    PortableGroup::GenericFactory::FactoryCreationId_out factory_creation_id
    ACE_ENV_ARG_DECL
    )
    ACE_THROW_SPEC ((
    CORBA::SystemException
    , PortableGroup::NoFactory
    , PortableGroup::ObjectNotCreated
    , PortableGroup::InvalidCriteria
    , PortableGroup::InvalidProperty
    , PortableGroup::CannotMeetCriteria
    )) ;

  virtual void delete_object (
    const PortableGroup::GenericFactory::FactoryCreationId & factory_creation_id
    ACE_ENV_ARG_DECL
    )
    ACE_THROW_SPEC ((
    CORBA::SystemException
    , PortableGroup::ObjectNotFound
    ));

private:
  CORBA::Object_ptr create_process (
    char * process,
    const PortableGroup::Criteria & the_criteria,
    PortableGroup::GenericFactory::FactoryCreationId_out factory_creation_id);

  const char* conf_file;
  int id;
  CORBA::ORB_ptr orb;
  typedef ACE_Hash_Map_Manager<int, CORBA::Object_var, ACE_Null_Mutex> Objects;
  Objects objects;
};
#endif

==> ace_5.4.7.orig.tar.gz: ACE_wrappers/TAO/orbsvcs/FTRT_Event_Service/Factory_Service/EventChannelFactory_i.h <==
// -*- C++ -*-

//=============================================================================
/**
 *  @file   EventChannelFactory_i.h
 *
 *  EventChannelFactory_i.h,v 1.7 2004/08/16 23:53:11 jtc Exp
 *
 *  @author Huang-Ming Huang <hh1@cse.wustl.edu>
 */
//=============================================================================

#ifndef EVENTCHANNELFACTORY_I_H
#define EVENTCHANNELFACTORY_I_H

#include "orbsvcs/FT_CORBAS.h"
#include "ace/Synch.h"
#include "ace/Hash_Map_Manager_T.h"

#if !defined (ACE_LACKS_PRAGMA_ONCE)
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */

class EventChannelFactory_i : public POA_PortableGroup::GenericFactory {
public:
  EventChannelFactory_i(const char* conf_filename, CORBA::ORB_ptr);

  virtual CORBA::Object_ptr create_object (
    const char * type_id,
    const PortableGroup::Criteria & the_criteria,
    PortableGroup::GenericFactory::FactoryCreationId_out factory_creation_id
    ACE_ENV_ARG_DECL
    )
    ACE_THROW_SPEC ((
    CORBA::SystemException
    , PortableGroup::NoFactory
    , PortableGroup::ObjectNotCreated
    , PortableGroup::InvalidCriteria
    , PortableGroup::InvalidProperty
    , PortableGroup::CannotMeetCriteria
    )) ;

  virtual void delete_object (
    const PortableGroup::GenericFactory::FactoryCreationId & factory_creation_id
    ACE_ENV_ARG_DECL
    )
    ACE_THROW_SPEC ((
    CORBA::SystemException
    , PortableGroup::ObjectNotFound
    ));

private:
  CORBA::Object_ptr create_process (
    char * process,
    const PortableGroup::Criteria & the_criteria,
    PortableGroup::GenericFactory::FactoryCreationId_out factory_creation_id);

  const char* conf_file;
  int id;
  CORBA::ORB_ptr orb;
  typedef ACE_Hash_Map_Manager<int, CORBA::Object_var, ACE_Null_Mutex> Objects;
  Objects objects;
};
#endif
